@@ -1068,7 +1068,7 @@ class Unet(nn.Module):
         scale_skip_connection = True,
         final_resnet_block = True,
         final_conv_kernel_size = 3,
-        pixel_shuffle_upsample = False        # may address checkboard artifacts
+        pixel_shuffle_upsample = True        # may address checkboard artifacts
     ):
         super().__init__()
 
@@ -2073,6 +2073,7 @@ class Imagen(nn.Module):
         unet_number = None,
         cond_images = None
     ):
+        assert images.shape[-1] == images.shape[-2], f'the images you pass in must be a square, but received dimensions of {images.shape[2]}, {images.shape[-1]}'
         assert not (len(self.unets) > 1 and not exists(unet_number)), f'you must specify which unet you want trained, from a range of 1 to {len(self.unets)}, if you are training cascading DDPM (multiple unets)'
         unet_number = default(unet_number, 1)
         assert not exists(self.only_train_unet_number) or self.only_train_unet_number == unet_number, 'you can only train on unet #{self.only_train_unet_number}'
